@@ -183,13 +183,23 @@ int xmp_get_error()
 
 bool xmp_init()
 {
-	// no need to initialize anything else.
-	return SXMPFiles::Initialize();
+	RESET_ERROR;
+	try {
+		// no need to initialize anything else.
+		// XMP SDK 5.1.2 needs this because it has been lobotomized of local text conversion
+		// the one that was done in Exempi with libiconv.
+		return SXMPFiles::Initialize(kXMPFiles_IgnoreLocalText);
+	}
+	catch(const XMP_Error & e) {
+		set_error(e);
+	}
+	return false;
 }
 
 
 void xmp_terminate()
 {
+	RESET_ERROR;
 	SXMPFiles::Terminate();
 }
 
@@ -213,6 +223,8 @@ bool xmp_register_namespace(const char *namespaceURI,
 
 bool xmp_namespace_prefix(const char *ns, XmpStringPtr prefix)
 {
+	CHECK_PTR(ns, false);
+	RESET_ERROR;
 	try {
 		return SXMPMeta::GetNamespacePrefix(ns,
 											STRING(prefix));
@@ -226,6 +238,8 @@ bool xmp_namespace_prefix(const char *ns, XmpStringPtr prefix)
 
 bool xmp_prefix_namespace_uri(const char *prefix, XmpStringPtr ns)
 {
+	CHECK_PTR(prefix, false);
+	RESET_ERROR;
 	try {
 		return SXMPMeta::GetNamespaceURI(prefix, STRING(ns));
 	}
@@ -371,6 +385,25 @@ bool xmp_files_put_xmp(XmpFilePtr xf, XmpPtr xmp)
 	return true;
 }
 
+bool xmp_files_get_file_info(XmpFilePtr xf, XmpStringPtr filePath, XmpOpenFileOptions *options,
+	XmpFileType * file_format, XmpFileFormatOptions *handler_flags)
+{
+	CHECK_PTR(xf, false);
+	RESET_ERROR;
+	
+	bool result = false;	
+	SXMPFiles *txf = (SXMPFiles*)xf;
+	try {
+		result = txf->GetFileInfo(STRING(filePath), (XMP_OptionBits *)options, 
+			(XMP_FileFormat *)file_format, (XMP_OptionBits *)handler_flags);
+	}
+	catch(const XMP_Error & e) {
+		set_error(e);
+		return false;
+	}
+	
+	return result;
+}
 
 bool xmp_files_free(XmpFilePtr xf)
 {
@@ -387,6 +420,36 @@ bool xmp_files_free(XmpFilePtr xf)
 	return true;
 }
 
+bool xmp_files_get_format_info(XmpFileType format, XmpFileFormatOptions * options)
+{
+	RESET_ERROR;
+
+	bool result = false;
+	try {
+		result = SXMPFiles::GetFormatInfo(format, (XMP_OptionBits*)options);	
+	}
+	catch(const XMP_Error & e) {
+		set_error(e);
+		return false;
+	}
+	return result;	
+}
+
+XmpFileType xmp_files_check_file_format(const char *filePath)
+{
+	CHECK_PTR(filePath, XMP_FT_UNKNOWN);
+	RESET_ERROR;
+
+	XmpFileType file_type = XMP_FT_UNKNOWN;
+	try {
+		file_type = (XmpFileType)SXMPFiles::CheckFileFormat(filePath);	
+	}
+	catch(const XMP_Error & e) {
+		set_error(e);
+		return XMP_FT_UNKNOWN;
+	}
+	return file_type;
+}
 
 XmpPtr xmp_new_empty()
 {
