@@ -1,6 +1,6 @@
 // =================================================================================================
 // ADOBE SYSTEMS INCORPORATED
-// Copyright 2006-2008 Adobe Systems Incorporated
+// Copyright 2006 Adobe Systems Incorporated
 // All Rights Reserved
 //
 // NOTICE: Adobe permits you to use, modify, and distribute this file in accordance with the terms
@@ -20,26 +20,15 @@
 // =================================================================================================
 // IsMetadataImgRsrc
 // =================
-//
-// The only image resources of possible interest as metadata have type '8BIM' and IDs:
-//    1008, 1020, 1028, 1034, 1035, 1036, 1058, 1060, 1061
 
 static inline bool IsMetadataImgRsrc ( XMP_Uns16 id )
 {
-
-	if ( (id < 1008) || (id > 1061) ) {
-		return false;
-	} else if ( id >= 1058 ) {
-		if ( id == 1059 ) return false;
-	} else if ( id > 1036 ) {
-		return false;
-	} else if ( id > 1028 ) {
-		if ( id < 1034 ) return false;
-	} else if ( id < 1028 ) {
-		if ( (id != 1008) && (id != 1020) ) return false;
-	}
-
-	return true;
+	if ( id == 0 ) return false;
+	
+	int i;
+	for ( i = 0; id < kPSIR_MetadataIDs[i]; ++i ) {}
+	if ( id == kPSIR_MetadataIDs[i] ) return true;
+	return false;
 
 }	// IsMetadataImgRsrc
 
@@ -97,9 +86,9 @@ bool PSIR_FileWriter::GetImgRsrc ( XMP_Uns16 id, ImgRsrcInfo* info ) const
 {
 	InternalRsrcMap::const_iterator rsrcPos = this->imgRsrcs.find ( id );
 	if ( rsrcPos == this->imgRsrcs.end() ) return false;
-	
+
 	const InternalRsrcInfo & rsrcInfo = rsrcPos->second;
-	
+
 	if ( info != 0 ) {
 		info->id = rsrcInfo.id;
 		info->dataLen = rsrcInfo.dataLen;
@@ -108,7 +97,7 @@ bool PSIR_FileWriter::GetImgRsrc ( XMP_Uns16 id, ImgRsrcInfo* info ) const
 	}
 
 	return true;
-	
+
 }	// PSIR_FileWriter::GetImgRsrc
 
 // =================================================================================================
@@ -126,7 +115,7 @@ void PSIR_FileWriter::SetImgRsrc ( XMP_Uns16 id, const void* clientPtr, XMP_Uns3
 		InternalRsrcMap::value_type mapValue ( id, InternalRsrcInfo ( id, length, this->fileParsed ) );
 		rsrcPos = this->imgRsrcs.insert ( rsrcPos, mapValue );
 		rsrcPtr = &rsrcPos->second;
-	
+
 	} else {
 
 		rsrcPtr = &rsrcPos->second;
@@ -136,12 +125,12 @@ void PSIR_FileWriter::SetImgRsrc ( XMP_Uns16 id, const void* clientPtr, XMP_Uns3
 			 (memcmp ( rsrcPtr->dataPtr, clientPtr, length ) == 0) ) {
 			return;
 		}
-		
+
 		rsrcPtr->FreeData();		// Release any existing data allocation.
 		rsrcPtr->dataLen = length;	// And this might be changing.
 
 	}
-	
+
 	rsrcPtr->changed = true;
 	rsrcPtr->dataPtr = malloc ( length );
 	if ( rsrcPtr->dataPtr == 0 ) XMP_Throw ( "Out of memory", kXMPErr_NoMemory );
@@ -159,7 +148,7 @@ void PSIR_FileWriter::DeleteImgRsrc ( XMP_Uns16 id )
 {
 	InternalRsrcMap::iterator rsrcPos = this->imgRsrcs.find ( id );
 	if ( rsrcPos == this->imgRsrcs.end() ) return;	// Nothing to delete.
-	
+
 	this->imgRsrcs.erase ( id );
 	this->changed = true;
 	if ( id != kPSIR_XMP ) this->legacyDeleted = true;
@@ -175,7 +164,7 @@ bool PSIR_FileWriter::IsLegacyChanged()
 
 	if ( ! this->changed ) return false;
 	if ( this->legacyDeleted ) return true;
-	
+
 	InternalRsrcMap::iterator irPos = this->imgRsrcs.begin();
 	InternalRsrcMap::iterator irEnd = this->imgRsrcs.end();
 
@@ -185,7 +174,7 @@ bool PSIR_FileWriter::IsLegacyChanged()
 	}
 
 	return false;	// Can get here if the XMP is the only thing changed.
-	
+
 }	// PSIR_FileWriter::IsLegacyChanged
 
 // =================================================================================================
@@ -199,7 +188,7 @@ void PSIR_FileWriter::ParseMemoryResources ( const void* data, XMP_Uns32 length,
 	if ( length == 0 ) return;
 
 	// Allocate space for the full in-memory data and copy it.
-	
+
 	if ( ! copyData ) {
 		this->memContent = (XMP_Uns8*) data;
 		XMP_Assert ( ! this->ownedContent );
@@ -211,15 +200,15 @@ void PSIR_FileWriter::ParseMemoryResources ( const void* data, XMP_Uns32 length,
 		this->ownedContent = true;
 	}
 	this->memLength = length;
-	
+
 	// Capture the info for all of the resources.
-	
+
 	XMP_Uns8* psirPtr   = this->memContent;
 	XMP_Uns8* psirEnd   = psirPtr + length;
 	XMP_Uns8* psirLimit = psirEnd - kMinImgRsrcSize;
-	
+
 	while ( psirPtr <= psirLimit ) {
-	
+
 		XMP_Uns8* origin = psirPtr;	// The beginning of this resource.
 		XMP_Uns32 type = GetUns32BE(psirPtr);
 		XMP_Uns16 id = GetUns16BE(psirPtr+4);
@@ -228,7 +217,7 @@ void PSIR_FileWriter::ParseMemoryResources ( const void* data, XMP_Uns32 length,
 		XMP_Uns8* namePtr = psirPtr;
 		XMP_Uns16 nameLen = namePtr[0];			// ! The length for the Pascal string, w/ room for "+2".
 		psirPtr += ((nameLen + 2) & 0xFFFE);	// ! Round up to an even offset. Yes, +2!
-		
+
 		if ( psirPtr > psirEnd-4 ) break;	// Bad image resource. Throw instead?
 
 		XMP_Uns32 dataLen = GetUns32BE(psirPtr);
@@ -236,9 +225,9 @@ void PSIR_FileWriter::ParseMemoryResources ( const void* data, XMP_Uns32 length,
 
 		XMP_Uns32 dataOffset = (XMP_Uns32) ( psirPtr - this->memContent );
 		XMP_Uns8* nextRsrc   = psirPtr + ((dataLen + 1) & 0xFFFFFFFEUL);	// ! Round up to an even offset.
-		
+
 		if ( (dataLen > length) || (psirPtr > psirEnd-dataLen) ) break;	// Bad image resource. Throw instead?
-		
+
 		if ( type == k8BIM ) {
 			InternalRsrcMap::value_type mapValue ( id, InternalRsrcInfo ( id, dataLen, kIsMemoryBased ) );
 			InternalRsrcMap::iterator rsrcPos = this->imgRsrcs.insert ( this->imgRsrcs.end(), mapValue );
@@ -252,9 +241,9 @@ void PSIR_FileWriter::ParseMemoryResources ( const void* data, XMP_Uns32 length,
 			XMP_Assert ( (rsrcLength & 1) == 0 );
 			this->otherRsrcs.push_back ( OtherRsrcInfo ( rsrcOffset, rsrcLength ) );
 		}
-		
+
 		psirPtr = nextRsrc;
-	
+
 	}
 
 }	// PSIR_FileWriter::ParseMemoryResources
@@ -266,28 +255,28 @@ void PSIR_FileWriter::ParseMemoryResources ( const void* data, XMP_Uns32 length,
 void PSIR_FileWriter::ParseFileResources ( LFA_FileRef fileRef, XMP_Uns32 length )
 {
 	bool ok;
-	
+
 	this->DeleteExistingInfo();
 	this->fileParsed = true;
 	if ( length == 0 ) return;
-	
+
 	// Parse the image resource block.
 
 	IOBuffer ioBuf;
 	ioBuf.filePos = LFA_Seek ( fileRef, 0, SEEK_CUR );
-	
+
 	XMP_Int64 psirOrigin = ioBuf.filePos;	// Need this to determine the resource data offsets.
 	XMP_Int64 fileEnd = ioBuf.filePos + length;
-	
+
 	std::string rsrcPName;
-	
+
 	while ( (ioBuf.filePos + (ioBuf.ptr - ioBuf.data)) < fileEnd ) {
-	
+
 		ok = CheckFileSpace ( fileRef, &ioBuf, 12 );	// The minimal image resource takes 12 bytes.
 		if ( ! ok ) break;	// Bad image resource. Throw instead?
 
 		XMP_Int64 thisRsrcPos = ioBuf.filePos + (ioBuf.ptr - ioBuf.data);
-	
+
 		XMP_Uns32 type = GetUns32BE(ioBuf.ptr);
 		XMP_Uns16 id   = GetUns16BE(ioBuf.ptr+4);
 		ioBuf.ptr += 6;	// Advance to the resource name.
@@ -296,7 +285,7 @@ void PSIR_FileWriter::ParseFileResources ( LFA_FileRef fileRef, XMP_Uns32 length
 		XMP_Uns16 paddedLen = (nameLen + 2) & 0xFFFE;	// ! Round up to an even total. Yes, +2!
 		ok = CheckFileSpace ( fileRef, &ioBuf, paddedLen+4 );	// Get the name text and the data length.
 		if ( ! ok ) break;	// Bad image resource. Throw instead?
-		
+
 		if ( nameLen > 0 ) rsrcPName.assign ( (char*)(ioBuf.ptr), paddedLen );	// ! Include the length byte and pad.
 
 		ioBuf.ptr += paddedLen;	// Move to the data length.
@@ -317,7 +306,7 @@ void PSIR_FileWriter::ParseFileResources ( LFA_FileRef fileRef, XMP_Uns32 length
 		InternalRsrcMap::value_type mapValue ( id, InternalRsrcInfo ( id, dataLen, kIsFileBased ) );
 		InternalRsrcMap::iterator newRsrc = this->imgRsrcs.insert ( this->imgRsrcs.end(), mapValue );
 		InternalRsrcInfo* rsrcPtr = &newRsrc->second;
-		
+
 		rsrcPtr->origOffset = (XMP_Uns32)thisDataPos;
 
 		if ( nameLen > 0 ) {
@@ -325,7 +314,7 @@ void PSIR_FileWriter::ParseFileResources ( LFA_FileRef fileRef, XMP_Uns32 length
 			if ( rsrcPtr->rsrcName == 0 ) XMP_Throw ( "Out of memory", kXMPErr_NoMemory );
 			memcpy ( (void*)rsrcPtr->rsrcName, rsrcPName.c_str(), paddedLen );	// AUDIT: Safe, allocated enough bytes above.
 		}
-		
+
 		if ( ! IsMetadataImgRsrc ( id ) ) {
 			MoveToOffset ( fileRef, nextRsrcPos, &ioBuf );
 			continue;
@@ -346,9 +335,9 @@ void PSIR_FileWriter::ParseFileResources ( LFA_FileRef fileRef, XMP_Uns32 length
 			LFA_Read ( fileRef, (void*)rsrcPtr->dataPtr, dataLen );
 			FillBuffer ( fileRef, nextRsrcPos, &ioBuf );
 		}
-		
+
 	}
-	
+
 	#if 0
 	{
 		printf ( "\nPSIR_FileWriter::ParseFileResources, count = %d\n", this->imgRsrcs.size() );
@@ -362,7 +351,7 @@ void PSIR_FileWriter::ParseFileResources ( LFA_FileRef fileRef, XMP_Uns32 length
 		}
 	}
 	#endif
-	
+
 }	// PSIR_FileWriter::ParseFileResources
 
 // =================================================================================================
@@ -372,9 +361,9 @@ void PSIR_FileWriter::ParseFileResources ( LFA_FileRef fileRef, XMP_Uns32 length
 XMP_Uns32 PSIR_FileWriter::UpdateMemoryResources ( void** dataPtr )
 {
 	if ( this->fileParsed ) XMP_Throw ( "Not memory based", kXMPErr_EnforceFailure );
-	
+
 	// Compute the size and allocate the new image resource block.
-	
+
 	XMP_Uns32 newLength = 0;
 
 	InternalRsrcMap::iterator irPos = this->imgRsrcs.begin();
@@ -391,27 +380,27 @@ XMP_Uns32 PSIR_FileWriter::UpdateMemoryResources ( void** dataPtr )
 			newLength += ((nameLen + 2) & 0xFFFFFFFEUL);	// ! Yes, +2.
 		}
 	}
-	
+
 	for ( size_t i = 0; i < this->otherRsrcs.size(); ++i ) {	// Add in the non-8BIM resources.
 		newLength += this->otherRsrcs[i].rsrcLength;
 	}
-	
+
 	XMP_Uns8* newContent = (XMP_Uns8*) malloc ( newLength );
 	if ( newContent == 0 ) XMP_Throw ( "Out of memory", kXMPErr_NoMemory );
-	
+
 	// Fill in the new image resource block.
-	
+
 	XMP_Uns8* rsrcPtr = newContent;
 
 	for ( irPos = this->imgRsrcs.begin(); irPos != irEnd; ++irPos ) {	// Do the 8BIM resources.
 
 		const InternalRsrcInfo & rsrcInfo = irPos->second;
-		
+
 		PutUns32BE ( k8BIM, rsrcPtr );
 		rsrcPtr += 4;
 		PutUns16BE ( rsrcInfo.id, rsrcPtr );
 		rsrcPtr += 2;
-		
+
 		if ( rsrcInfo.rsrcName == 0 ) {
 			PutUns16BE ( 0, rsrcPtr );
 			rsrcPtr += 2;
@@ -427,7 +416,7 @@ XMP_Uns32 PSIR_FileWriter::UpdateMemoryResources ( void** dataPtr )
 				++rsrcPtr;
 			}
 		}
-		
+
 		PutUns32BE ( rsrcInfo.dataLen, rsrcPtr );
 		rsrcPtr += 4;
 		if ( rsrcInfo.dataLen > (newLength - (rsrcPtr - newContent)) ) {
@@ -451,17 +440,17 @@ XMP_Uns32 PSIR_FileWriter::UpdateMemoryResources ( void** dataPtr )
 		memcpy ( rsrcPtr, srcPtr, srcLen );	// AUDIT: Protected by the above check.
 		rsrcPtr += srcLen;	// No need to pad, included in the original resource length.
 	}
-	
+
 	XMP_Assert ( rsrcPtr == (newContent + newLength) );
-	
+
 	// Parse the rebuilt image resource block. This is the easiest way to reconstruct the map.
-	
+
 	this->ParseMemoryResources ( newContent, newLength, false );
 	this->ownedContent = (newLength > 0);	// ! We really do own the new content, if not empty.
-	
+
 	if ( dataPtr != 0 ) *dataPtr = newContent;
 	return newLength;
-	
+
 }	// PSIR_FileWriter::UpdateMemoryResources
 
 // =================================================================================================
@@ -473,20 +462,20 @@ XMP_Uns32 PSIR_FileWriter::UpdateFileResources ( LFA_FileRef sourceRef, LFA_File
 {
 	IgnoreParam(ioBuf);
 	const XMP_Uns32 zero32 = 0;
-	
+
 	const bool checkAbort = (abortProc != 0);
-	
+
 	struct RsrcHeader {
 		XMP_Uns32 type;
 		XMP_Uns16 id;
 	};
 	XMP_Assert ( (offsetof(RsrcHeader,type) == 0) && (offsetof(RsrcHeader,id) == 4) );
-	
+
 	if ( this->memParsed ) XMP_Throw ( "Not file based", kXMPErr_EnforceFailure );
-	
+
 	XMP_Int64 destLenOffset = LFA_Seek ( destRef, 0, SEEK_CUR );
 	XMP_Uns32 destLength = 0;
-	
+
 	LFA_Write ( destRef, &destLength, 4 );	// Write a placeholder for the new PSIR section length.
 
 	#if 0
@@ -502,7 +491,7 @@ XMP_Uns32 PSIR_FileWriter::UpdateFileResources ( LFA_FileRef sourceRef, LFA_File
 		}
 	}
 	#endif
-	
+
 	// First write all of the '8BIM' resources from the map. Use the internal data if present, else
 	// copy the data from the file.
 
@@ -516,11 +505,11 @@ XMP_Uns32 PSIR_FileWriter::UpdateFileResources ( LFA_FileRef sourceRef, LFA_File
 	for ( ; rsrcPos != rsrcEnd; ++rsrcPos ) {
 
 		InternalRsrcInfo& currRsrc = rsrcPos->second;
-		
+
 		outHeader.id = MakeUns16BE ( currRsrc.id );
 		LFA_Write ( destRef, &outHeader, 6 );
 		destLength += 6;
-		
+
 		if ( currRsrc.rsrcName == 0 ) {
 			LFA_Write ( destRef, &zero32, 2 );
 			destLength += 2;
@@ -531,7 +520,7 @@ XMP_Uns32 PSIR_FileWriter::UpdateFileResources ( LFA_FileRef sourceRef, LFA_File
 			LFA_Write ( destRef, currRsrc.rsrcName, paddedLen );
 			destLength += paddedLen;
 		}
-		
+
 		XMP_Uns32 dataLen = MakeUns32BE ( currRsrc.dataLen );
 		LFA_Write ( destRef, &dataLen, 4 );
 		// printf ( "  #%d, offset %d (0x%X), dataLen %d\n", currRsrc.id, destLength, destLength, currRsrc.dataLen );
@@ -542,18 +531,18 @@ XMP_Uns32 PSIR_FileWriter::UpdateFileResources ( LFA_FileRef sourceRef, LFA_File
 			LFA_Seek ( sourceRef, currRsrc.origOffset, SEEK_SET );
 			LFA_Copy ( sourceRef, destRef, currRsrc.dataLen );
 		}
-		
+
 		destLength += 4 + currRsrc.dataLen;
-		
+
 		if ( (currRsrc.dataLen & 1) != 0 ) {
 			LFA_Write ( destRef, &zero32, 1 );	// ! Pad the data to an even length.
 			++destLength;
 		}
 
 	}
-	
+
 	// Now write all of the non-8BIM resources. Copy the entire resource chunk from the source file.
-	
+
 	// printf ( "\nPSIR_FileWriter::UpdateFileResources - other resources\n" );
 	for ( size_t i = 0; i < this->otherRsrcs.size(); ++i ) {
 		// printf ( "  offset %d (0x%X), length %d",
@@ -570,7 +559,7 @@ XMP_Uns32 PSIR_FileWriter::UpdateFileResources ( LFA_FileRef sourceRef, LFA_File
 	XMP_Uns32 outLen = MakeUns32BE ( destLength );
 	LFA_Write ( destRef, &outLen, 4 );
 	LFA_Seek ( destRef, 0, SEEK_END );
-	
+
 	// *** Not rebuilding the internal map - turns out we never want it, why pay for the I/O.
 	// *** Should probably add an option for all of these cases, memory and file based.
 
