@@ -13,7 +13,7 @@
 // LFA implementations for Macintosh
 // =================================
 
-#if XMP_MacBuild
+#if 0 // This Mac-specific code is no longer used, but retained to make merges easier
 
 	static bool FileExists ( const char * filePath )
 	{
@@ -505,7 +505,7 @@
 // LFA implementations for POSIX
 // =============================
 
-#if XMP_UNIXBuild
+#if XMP_UNIXBuild | XMP_MacBuild
 
 	// ---------------------------------------------------------------------------------------------
 
@@ -688,7 +688,7 @@
 
 	// ---------------------------------------------------------------------------------------------
 
-#endif	// XMP_UNIXBuild
+#endif	// XMP_UNIXBuild | XMP_MacBuild
 
 // =================================================================================================
 
@@ -798,7 +798,7 @@ XMP_Int64 LFA_Rewind( LFA_FileRef file)
 //*** kind of a hack, TOTEST
 bool LFA_isEof( LFA_FileRef file )
 {
-	#if XMP_MacBuild
+	#if 0 // This Mac-specific code is no longer used, but retained to make merges easier
 		long refNum = (long)file;	// ! Use long to avoid size warnings for SInt16 cast.
 		
 		XMP_Int64 position, length;
@@ -825,7 +825,7 @@ bool LFA_isEof( LFA_FileRef file )
 		return filesize == filepos;
 	#endif
 	
-	#if XMP_UNIXBuild
+	#if XMP_UNIXBuild | XMP_MacBuild
 		int descr = (int)file;
 
 		struct stat info; 
@@ -843,3 +843,34 @@ char LFA_GetChar( LFA_FileRef file )
 	LFA_Read( file, &c, 1, true);
 	return c;
 }
+
+#if XMP_MacBuild
+
+	// ---------------------------------------------------------------------------------------------
+
+	// On Mac OS X, POSIX open() can access resource forks by appending
+	// "/..namedfork/rsrc" to the end of the actual path
+	LFA_FileRef LFA_OpenRsrc ( const char* filePath, char mode )
+	{
+		char suffix[18] = "/..namedfork/rsrc";
+		char* rsrc = (char*) malloc((strlen(filePath)+strlen(suffix)+2) * sizeof(char));
+		strcpy ( rsrc, filePath ) ;
+		strcat ( rsrc, suffix );
+
+		LFA_FileRef fileRef;
+		try {
+			// Once we assemble the name with resource fork, we can use
+			// the standard LFA_Open call to get it
+			fileRef = LFA_Open ( rsrc, mode );
+		} catch ( ... ) {
+			LFA_Throw ( "LFA_OpenRsrc: open failure", kLFAErr_ExternalFailure );
+		}
+
+		free ( rsrc );
+
+		return fileRef;
+	} // LFA_OpenRsrc
+
+	// ---------------------------------------------------------------------------------------------
+
+#endif // XMP_MacBuild
